@@ -11,7 +11,7 @@ from devsecops_engine_tools.engine_utilities.git_cli.infrastructure.git_run impo
     GitRun
     )
 
-def runner_secret_scan(dict_args, tool, devops_platform_gateway):
+def runner_secret_scan(dict_args, tool, devops_platform_gateway, secret_tool):
     try:
         tool_deserealizator = None
         tool_gateway = None
@@ -25,7 +25,8 @@ def runner_secret_scan(dict_args, tool, devops_platform_gateway):
             dict_args = dict_args,
             tool=tool,
             tool_deserealizator = tool_deserealizator,
-            git_gateway = git_gateway
+            git_gateway = git_gateway,
+            secret_tool = secret_tool
         )
     except Exception as e:
         raise Exception(f"Error engine_secret : {str(e)}")
